@@ -3,7 +3,7 @@ package Apache::Session::Browseable::Store::LDAP;
 use strict;
 use Net::LDAP;
 
-our $VERSION = '1.2.2';
+our $VERSION = '1.3.7';
 
 sub new {
     my $class = shift;
@@ -162,9 +162,9 @@ sub ldap {
     my $ldap = Net::LDAP->new(
         \@servers,
         onerror => undef,
-        verify => $self->{args}->{ldapVerify} || "require",
-	( $caFile ? ( cafile => $caFile ) : () ),
-	( $caPath ? ( capath => $caPath ) : () ),
+        verify  => $self->{args}->{ldapVerify} || "require",
+        ( $caFile ? ( cafile => $caFile ) : () ),
+        ( $caPath ? ( capath => $caPath ) : () ),
 
         (
             $self->{args}->{ldapRaw} ? ( raw => $self->{args}->{ldapRaw} )
@@ -180,9 +180,9 @@ sub ldap {
 
     if ($useTls) {
         my %h = split( /[&=]/, $tlsParam );
-        $h{verify} = $self->{args}->{ldapVerify} || "require";
-        $h{cafile} = $caFile if ( $caFile );
-        $h{capath} = $caPath if ( $caPath );
+        $h{verify} ||= ( $self->{args}->{ldapVerify} || "require" );
+        $h{cafile} ||= $caFile if ($caFile);
+        $h{capath} ||= $caPath if ($caPath);
         my $start_tls = $ldap->start_tls(%h);
         if ( $start_tls->code ) {
             $self->logError($start_tls);
